@@ -58,7 +58,7 @@ class Passwd():
         :param user2:
         :return:
         """
-        if user1.name == user2.name or user1.uid == user2.uid:
+        if user1.name == user2.name or user1.base_uid == user2.base_uid:
             return True
         return False
 
@@ -98,19 +98,19 @@ class Passwd():
         uid_map = {}
         for user in self.users:
             for user2 in passwd.users:
-                if user.name == user2.name and user.uid != user2.uid:
+                if user.name == user2.name and user.uid != user2.base_uid:
                     try:
-                        uid_map[int(user.uid)] = int(user2.uid)
+                        uid_map[int(user.uid)] = int(user2.base_uid)
                     except ValueError:
                         raise AccountsError(
                             _("Wrong UIDs {uid1} {uid2}").format(
-                                uid1=user.uid, uid2=user2.uid))
+                                uid1=user.uid, uid2=user2.base_uid))
         return uid_map
 
     def format_user(self, user):
         return "{0}:{1}:{2}:{3}:{4}:{5}:{6}".format(
-            user.name, user.password, user.uid,
-            user.gid, user.gecos, user.homedir, user.shell)
+            user.name, user.password, user.base_uid,
+            user.base_gid, user.gecos, user.homedir, user.shell)
 
     def write(self, f):
         for user in self.users:
@@ -144,7 +144,7 @@ class Group():
         :param group2:
         :return:
         """
-        if group1.name == group2.name or group1.gid == group2.gid:
+        if group1.name == group2.name or group1.base_gid == group2.base_gid:
             return True
         return False
 
@@ -196,18 +196,18 @@ class Group():
         gid_map = {}
         for group in self.groups:
             for group2 in groupobj.groups:
-                if group.name == group2.name and group.gid != group2.gid:
+                if group.name == group2.name and group.gid != group2.base_gid:
                     try:
-                        gid_map[int(group.gid)] = int(group2.gid)
+                        gid_map[int(group.gid)] = int(group2.base_gid)
                     except ValueError:
                         raise AccountsError(
                             _("Wrong GIDs {gid1} {gid2}").format(
-                                gid1=group.gid, gid2=group2.gid))
+                                gid1=group.gid, gid2=group2.base_gid))
         return gid_map
 
     def format_group(self, group):
         return "{0}:{1}:{2}:{3}".format(
-            group.name, group.password, group.gid, group.user_list)
+            group.name, group.password, group.base_gid, group.user_list)
 
     def write(self, f):
         for group in self.groups:
